@@ -21,9 +21,9 @@ public:
         : KPackage::Package(new KPackage::PackageStructure)
     {
         setContentsPrefixPaths(QStringList());
-        addDirectoryDefinition("bin", QStringLiteral("bin"), QStringLiteral("bin"));
-        addFileDefinition("MultiplePaths", QStringLiteral("first"), QStringLiteral("Description proper"));
-        addFileDefinition("MultiplePaths", QStringLiteral("second"), QStringLiteral("Description proper"));
+        addDirectoryDefinition("bin", QStringLiteral("bin"));
+        addFileDefinition("MultiplePaths", QStringLiteral("first"));
+        addFileDefinition("MultiplePaths", QStringLiteral("second"));
         setPath(QStringLiteral("/"));
     }
 };
@@ -34,14 +34,13 @@ class Wallpaper : public KPackage::PackageStructure
 public:
     void initPackage(KPackage::Package *package) override
     {
-        package->addDirectoryDefinition("images", QStringLiteral("images/"), i18n("Images"));
+        package->addDirectoryDefinition("images", QStringLiteral("images/"));
 
-        QStringList mimetypes;
-        mimetypes << QStringLiteral("image/svg") << QStringLiteral("image/png") << QStringLiteral("image/jpeg") << QStringLiteral("image/jpg");
+        const QStringList mimetypes{QStringLiteral("image/svg"), QStringLiteral("image/png"), QStringLiteral("image/jpeg"), QStringLiteral("image/jpg")};
         package->setMimeTypes("images", mimetypes);
 
         package->setRequired("images", true);
-        package->addFileDefinition("screenshot", QStringLiteral("screenshot.png"), i18n("Screenshot"));
+        package->addFileDefinition("screenshot", QStringLiteral("screenshot.png"));
         package->setAllowExternalPaths(true);
     }
     void pathChanged(KPackage::Package *package) override
@@ -67,10 +66,10 @@ public:
         package->setRequired("images", isFullPackage);
 
         if (isFullPackage) {
-            package->setContentsPrefixPaths(QStringList() << QStringLiteral("contents/"));
+            package->setContentsPrefixPaths(QStringList{QStringLiteral("contents/")});
         } else {
-            package->addFileDefinition("screenshot", info.fileName(), i18n("Preview"));
-            package->addFileDefinition("preferred", info.fileName(), QString());
+            package->addFileDefinition("screenshot", info.fileName());
+            package->addFileDefinition("preferred", info.fileName());
             package->setContentsPrefixPaths(QStringList());
             package->setPath(info.path());
         }
@@ -85,17 +84,15 @@ class SimpleContent : public KPackage::PackageStructure
 public:
     void initPackage(KPackage::Package *package) override
     {
-        package->addDirectoryDefinition("ui", QStringLiteral("ui/"), i18n("User interface"));
+        package->addDirectoryDefinition("ui", QStringLiteral("ui/"));
     }
     void pathChanged(KPackage::Package *package) override
     {
         if (!package->metadata().isValid()) {
             return;
         }
-        if (readKPackageTypes(package->metadata()).contains(QStringLiteral("CustomContent"))) {
-            package->addFileDefinition("customcontentfile",
-                                       QStringLiteral("customcontent/CustomContentFile.qml"),
-                                       i18n("Custom file only for packages that contain CustomContent in their servicetypes"));
+        if (readKPackageType(package->metadata()) == QStringLiteral("KPackage/CustomContent")) {
+            package->addFileDefinition("customcontentfile", QStringLiteral("customcontent/CustomContentFile.qml"));
         } else {
             package->removeDefinition("customcontentfile");
         }
@@ -105,8 +102,7 @@ public:
 void PackageStructureTest::initTestCase()
 {
     m_packagePath = QFINDTESTDATA("data/testpackage");
-    ps = KPackage::PackageLoader::self()->loadPackage(QStringLiteral("KPackage/Generic"));
-    ps.addFileDefinition("mainscript", QStringLiteral("ui/main.qml"), i18n("Main Script File"));
+    ps = KPackage::PackageLoader::self()->loadPackage(QStringLiteral("KPackage/GenericQML"));
     ps.setPath(m_packagePath);
 }
 
@@ -125,7 +121,7 @@ void PackageStructureTest::validPackages()
     QVERIFY(NoPrefixes().isValid());
 
     KPackage::Package p = KPackage::PackageLoader::self()->loadPackage(QStringLiteral("KPackage/Generic"));
-    p.addFileDefinition("mainscript", QStringLiteral("ui/main.qml"), i18n("Main Script File"));
+    p.addFileDefinition("mainscript", QStringLiteral("ui/main.qml"));
     QVERIFY(!p.isValid());
     p.setPath(QStringLiteral("/does/not/exist"));
     QVERIFY(!p.isValid());
@@ -144,18 +140,6 @@ void PackageStructureTest::wallpaperPackage()
     QVERIFY(p2.isValid());
 }
 
-void PackageStructureTest::copyPerformance()
-{
-    // seed the cache first
-    ps.filePath("mainscript");
-
-    QBENCHMARK {
-        KPackage::Package foo(ps);
-        const QString bar = foo.filePath("mainscript");
-        Q_UNUSED(bar);
-    }
-}
-
 void PackageStructureTest::mutateAfterCopy()
 {
     const bool mainscriptRequired = ps.isRequired("mainscript");
@@ -185,19 +169,18 @@ void PackageStructureTest::mutateAfterCopy()
     QCOMPARE(copy.allowExternalPaths(), !externalPaths);
 
     copy = ps;
-    QStringList copyContentsPrefixPaths = contentsPrefixPaths;
-    copyContentsPrefixPaths << QStringLiteral("more/");
+    const QStringList copyContentsPrefixPaths = QStringList(contentsPrefixPaths) << QStringLiteral("more/");
     copy.setContentsPrefixPaths(copyContentsPrefixPaths);
     QCOMPARE(ps.contentsPrefixPaths(), contentsPrefixPaths);
     QCOMPARE(copy.contentsPrefixPaths(), copyContentsPrefixPaths);
 
     copy = ps;
-    copy.addFileDefinition("nonsense", QStringLiteral("foobar"), QString());
+    copy.addFileDefinition("nonsense", QStringLiteral("foobar"));
     QCOMPARE(ps.files(), files);
     QVERIFY(ps.files() != copy.files());
 
     copy = ps;
-    copy.addDirectoryDefinition("nonsense", QStringLiteral("foobar"), QString());
+    copy.addDirectoryDefinition("nonsense", QStringLiteral("foobar"));
     QCOMPARE(ps.directories(), dirs);
     QVERIFY(ps.directories() != copy.directories());
 
@@ -208,15 +191,13 @@ void PackageStructureTest::mutateAfterCopy()
 
     copy = ps;
     QVERIFY(!imageMimeTypes.isEmpty());
-    QStringList copyMimeTypes;
-    copyMimeTypes << imageMimeTypes.first();
+    const QStringList copyMimeTypes(imageMimeTypes.first());
     copy.setMimeTypes("images", copyMimeTypes);
     QCOMPARE(ps.mimeTypes("images"), imageMimeTypes);
     QCOMPARE(copy.mimeTypes("images"), copyMimeTypes);
 
     copy = ps;
-    QStringList copyDefaultMimeTypes = defaultMimeTypes;
-    copyDefaultMimeTypes << QStringLiteral("rubbish");
+    const QStringList copyDefaultMimeTypes = QStringList(defaultMimeTypes) << QStringLiteral("rubbish");
     copy.setDefaultMimeTypes(copyDefaultMimeTypes);
     QCOMPARE(ps.mimeTypes("translations"), defaultMimeTypes);
     QCOMPARE(copy.mimeTypes("translations"), copyDefaultMimeTypes);
@@ -226,28 +207,22 @@ void PackageStructureTest::emptyContentsPrefix()
 {
     NoPrefixes package;
     QString path(package.filePath("bin", QStringLiteral("ls")));
-    // qDebug() << path;
     if (QFileInfo::exists(QStringLiteral("/bin/ls"))) { // not Windows
         QCOMPARE(path, QStringLiteral("/bin/ls"));
     }
 }
 
-void PackageStructureTest::multiplePaths()
-{
-    NoPrefixes package;
-    QCOMPARE(package.name("MultiplePaths"), QStringLiteral("Description proper"));
-}
-
 void PackageStructureTest::directories()
 {
-    QList<QByteArray> dirs;
-    dirs << "config"
-         << "data"
-         << "images"
-         << "theme"
-         << "scripts"
-         << "translations"
-         << "ui";
+    const QList<QByteArray> dirs{
+        "config",
+        "data",
+        "images",
+        "theme",
+        "scripts",
+        "translations",
+        "ui",
+    };
 
     const QList<QByteArray> psDirs = ps.directories();
 
@@ -284,16 +259,14 @@ void PackageStructureTest::requiredDirectories()
 
 void PackageStructureTest::files()
 {
-    QList<QByteArray> files;
-    files << "mainconfigui"
-          << "mainconfigxml"
-          << "mainscript";
+    const QList<QByteArray> files{
+        "mainconfigui",
+        "mainconfigxml",
+        "mainscript",
+    };
 
     const QList<QByteArray> psFiles = ps.files();
 
-    // for (int i = 0; i < psFiles.count(); ++i) {
-    //    qDebug() << psFiles[i];
-    //}
     for (const char *file : psFiles) {
         bool found = false;
         for (const char *check : std::as_const(files)) {
@@ -308,15 +281,9 @@ void PackageStructureTest::files()
 
 void PackageStructureTest::requiredFiles()
 {
-    QList<QByteArray> files;
-    files << "mainscript";
-
-    QList<QByteArray> psFiles = ps.requiredFiles();
-
-    QCOMPARE(files.count(), psFiles.count());
-    for (int i = 0; i < files.count(); ++i) {
-        QCOMPARE(files[i], psFiles[i]);
-    }
+    const QList<QByteArray> files{"mainscript"};
+    const QList<QByteArray> psFiles = ps.requiredFiles();
+    QCOMPARE(files, psFiles);
 }
 
 void PackageStructureTest::path()
@@ -326,12 +293,6 @@ void PackageStructureTest::path()
     QCOMPARE(ps.filePath("mainscript"), QFileInfo(m_packagePath + QLatin1String("/contents/ui/main.qml")).canonicalFilePath());
 }
 
-void PackageStructureTest::name()
-{
-    QCOMPARE(ps.name("config"), i18n("Configuration Definitions"));
-    QCOMPARE(ps.name("mainscript"), i18n("Main Script File"));
-}
-
 void PackageStructureTest::required()
 {
     QVERIFY(ps.isRequired("mainscript"));
@@ -339,8 +300,7 @@ void PackageStructureTest::required()
 
 void PackageStructureTest::mimeTypes()
 {
-    QStringList mimeTypes;
-    mimeTypes << QStringLiteral("image/svg+xml") << QStringLiteral("image/png") << QStringLiteral("image/jpeg");
+    const QStringList mimeTypes{QStringLiteral("image/svg+xml"), QStringLiteral("image/png"), QStringLiteral("image/jpeg")};
     QCOMPARE(ps.mimeTypes("images"), mimeTypes);
     QCOMPARE(ps.mimeTypes("theme"), mimeTypes);
 }
